/v1/vpcs/{uuid} — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /v1/vpcs/{uuid}

Contents

- /v1/vpcs/{uuid}
  - GET /v1/vpcs/{uuid}
    - Parameters
    - Response status codes
    - Output
  - PUT /v1/vpcs/{uuid}
    - Parameters
    - Response status codes
    - Input
    - Output
  - DELETE /v1/vpcs/{uuid}
    - Parameters
    - Response status codes

## GET /v1/vpcs/{uuid}

Get a VPCS instance

### Parameters

- uuid: Instance UUID

### Response status codes

- 200: Success
- 404: Instance doesn’t exist

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
name | ✔ | string | VPCS device name
project_id | ✔ | string | Project UUID
script_file |  | ['string', 'null'] | VPCS startup script
startup_script |  | ['string', 'null'] | Content of the VPCS startup script
uuid | ✔ | string | VPCS device UUID

## PUT /v1/vpcs/{uuid}

Update a VPCS instance

### Parameters

- uuid: Instance UUID

### Response status codes

- 200: Instance updated
- 409: Conflict
- 404: Instance doesn’t exist

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
console |  | ['integer', 'null'] | console TCP port
name |  | ['string', 'null'] | VPCS device name
startup_script |  | ['string', 'null'] | Content of the VPCS startup script

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
name | ✔ | string | VPCS device name
project_id | ✔ | string | Project UUID
script_file |  | ['string', 'null'] | VPCS startup script
startup_script |  | ['string', 'null'] | Content of the VPCS startup script
uuid | ✔ | string | VPCS device UUID

## DELETE /v1/vpcs/{uuid}

Delete a VPCS instance

### Parameters

- uuid: Instance UUID

### Response status codes

- 404: Instance doesn’t exist
- 204: Instance deleted

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »